@@ -1,5 +1,7 @@
 from circle.resources.ach import Ach
 from circle.resources.card import Card
+from circle.resources.message import Message
+from circle.resources.notification import Notification
 from circle.resources.payment import Payment
 from circle.resources.payout import Payout
 from circle.resources.public_key import PublicKey
